@@ -1,18 +1,18 @@
 /* marray/file_source.c
- * 
+ *
  * Copyright (C) 2002, 2003, 2004, 2005, 2007 Jordi Burguet-Castell
  * based on the gsl_matrix code from Gerard Jungman, Brian Gough
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to:
  *   Free Software Foundation, Inc.
@@ -86,7 +86,7 @@ FUNCTION(marray, fprintf) (FILE * stream, const TYPE(marray) * t,
         {
           GSL_ERROR ("fprintf failed", GSL_EFAILED);
         }
-      
+
       status = putc ('\n', stream);
 
       if (status == EOF)
@@ -112,12 +112,14 @@ FUNCTION(marray, fscanf) (FILE * stream, TYPE(marray) * t)
   for (i = 0; i < n; i++)
     {
 #if defined(BASE_COMPLEX_DOUBLE)
+      ATOMIC * real = (&data[i]);
+      ATOMIC * imag = (&data[i]) + 1;
       ATOMIC_IO tmp1;
       ATOMIC_IO tmp2;
       status = fscanf(stream, IN_FORMAT, &tmp1);
       status = fscanf(stream, IN_FORMAT, &tmp2);
-      *(&data[i]) = tmp1;
-      *(&(double)data[i]+1) = tmp2;
+      *real = tmp1;
+      *imag = tmp2;
 #else
       ATOMIC_IO tmp;
       status = fscanf(stream, IN_FORMAT, &tmp) ;
